@@ -1935,7 +1935,8 @@ about_cb (GtkAction * action, gpointer data)
 			 "comments",
 			 _("GNOME Tetravex is a simple puzzle where "
 			   "pieces must be positioned so that the "
-			   "same numbers are touching each other."),
+			   "same numbers are touching each other.\n\n"
+			   "Tetravex is a part of GNOME Games."),
 			 "copyright",
 			 "Copyright \xc2\xa9 1999-2007 Lars Rydlinge",
 			 "license", license,
